#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SubCheckLabel import SubCheckLabel


class DetectCheckLabel(object):

    def __init__(self):
        self._label = None
        self._rate = None
        self._sub_check_labels = None

    @property
    def label(self):
        return self._label

    @label.setter
    def label(self, value):
        self._label = value
    @property
    def rate(self):
        return self._rate

    @rate.setter
    def rate(self, value):
        self._rate = value
    @property
    def sub_check_labels(self):
        return self._sub_check_labels

    @sub_check_labels.setter
    def sub_check_labels(self, value):
        if isinstance(value, list):
            self._sub_check_labels = list()
            for i in value:
                if isinstance(i, SubCheckLabel):
                    self._sub_check_labels.append(i)
                else:
                    self._sub_check_labels.append(SubCheckLabel.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.label:
            if hasattr(self.label, 'to_alipay_dict'):
                params['label'] = self.label.to_alipay_dict()
            else:
                params['label'] = self.label
        if self.rate:
            if hasattr(self.rate, 'to_alipay_dict'):
                params['rate'] = self.rate.to_alipay_dict()
            else:
                params['rate'] = self.rate
        if self.sub_check_labels:
            if isinstance(self.sub_check_labels, list):
                for i in range(0, len(self.sub_check_labels)):
                    element = self.sub_check_labels[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sub_check_labels[i] = element.to_alipay_dict()
            if hasattr(self.sub_check_labels, 'to_alipay_dict'):
                params['sub_check_labels'] = self.sub_check_labels.to_alipay_dict()
            else:
                params['sub_check_labels'] = self.sub_check_labels
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DetectCheckLabel()
        if 'label' in d:
            o.label = d['label']
        if 'rate' in d:
            o.rate = d['rate']
        if 'sub_check_labels' in d:
            o.sub_check_labels = d['sub_check_labels']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCampaignCashCreateModel(object):

    def __init__(self):
        self._coupon_name = None
        self._end_time = None
        self._merchant_link = None
        self._prize_msg = None
        self._prize_type = None
        self._send_freqency = None
        self._start_time = None
        self._total_money = None
        self._total_num = None

    @property
    def coupon_name(self):
        return self._coupon_name

    @coupon_name.setter
    def coupon_name(self, value):
        self._coupon_name = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def merchant_link(self):
        return self._merchant_link

    @merchant_link.setter
    def merchant_link(self, value):
        self._merchant_link = value
    @property
    def prize_msg(self):
        return self._prize_msg

    @prize_msg.setter
    def prize_msg(self, value):
        self._prize_msg = value
    @property
    def prize_type(self):
        return self._prize_type

    @prize_type.setter
    def prize_type(self, value):
        self._prize_type = value
    @property
    def send_freqency(self):
        return self._send_freqency

    @send_freqency.setter
    def send_freqency(self, value):
        self._send_freqency = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def total_money(self):
        return self._total_money

    @total_money.setter
    def total_money(self, value):
        self._total_money = value
    @property
    def total_num(self):
        return self._total_num

    @total_num.setter
    def total_num(self, value):
        self._total_num = value


    def to_alipay_dict(self):
        params = dict()
        if self.coupon_name:
            if hasattr(self.coupon_name, 'to_alipay_dict'):
                params['coupon_name'] = self.coupon_name.to_alipay_dict()
            else:
                params['coupon_name'] = self.coupon_name
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.merchant_link:
            if hasattr(self.merchant_link, 'to_alipay_dict'):
                params['merchant_link'] = self.merchant_link.to_alipay_dict()
            else:
                params['merchant_link'] = self.merchant_link
        if self.prize_msg:
            if hasattr(self.prize_msg, 'to_alipay_dict'):
                params['prize_msg'] = self.prize_msg.to_alipay_dict()
            else:
                params['prize_msg'] = self.prize_msg
        if self.prize_type:
            if hasattr(self.prize_type, 'to_alipay_dict'):
                params['prize_type'] = self.prize_type.to_alipay_dict()
            else:
                params['prize_type'] = self.prize_type
        if self.send_freqency:
            if hasattr(self.send_freqency, 'to_alipay_dict'):
                params['send_freqency'] = self.send_freqency.to_alipay_dict()
            else:
                params['send_freqency'] = self.send_freqency
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.total_money:
            if hasattr(self.total_money, 'to_alipay_dict'):
                params['total_money'] = self.total_money.to_alipay_dict()
            else:
                params['total_money'] = self.total_money
        if self.total_num:
            if hasattr(self.total_num, 'to_alipay_dict'):
                params['total_num'] = self.total_num.to_alipay_dict()
            else:
                params['total_num'] = self.total_num
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCampaignCashCreateModel()
        if 'coupon_name' in d:
            o.coupon_name = d['coupon_name']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'merchant_link' in d:
            o.merchant_link = d['merchant_link']
        if 'prize_msg' in d:
            o.prize_msg = d['prize_msg']
        if 'prize_type' in d:
            o.prize_type = d['prize_type']
        if 'send_freqency' in d:
            o.send_freqency = d['send_freqency']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'total_money' in d:
            o.total_money = d['total_money']
        if 'total_num' in d:
            o.total_num = d['total_num']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceOperationUserPointRefundModel(object):

    def __init__(self):
        self._exchange_request_id = None
        self._open_id = None
        self._refund_reason = None
        self._request_id = None
        self._scene_code = None
        self._source = None
        self._user_id = None

    @property
    def exchange_request_id(self):
        return self._exchange_request_id

    @exchange_request_id.setter
    def exchange_request_id(self, value):
        self._exchange_request_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def refund_reason(self):
        return self._refund_reason

    @refund_reason.setter
    def refund_reason(self, value):
        self._refund_reason = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.exchange_request_id:
            if hasattr(self.exchange_request_id, 'to_alipay_dict'):
                params['exchange_request_id'] = self.exchange_request_id.to_alipay_dict()
            else:
                params['exchange_request_id'] = self.exchange_request_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.refund_reason:
            if hasattr(self.refund_reason, 'to_alipay_dict'):
                params['refund_reason'] = self.refund_reason.to_alipay_dict()
            else:
                params['refund_reason'] = self.refund_reason
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceOperationUserPointRefundModel()
        if 'exchange_request_id' in d:
            o.exchange_request_id = d['exchange_request_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'refund_reason' in d:
            o.refund_reason = d['refund_reason']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'source' in d:
            o.source = d['source']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEbppProdmodeAgreementUploadResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppProdmodeAgreementUploadResponse, self).__init__()
        self._is_success = None
        self._memo = None

    @property
    def is_success(self):
        return self._is_success

    @is_success.setter
    def is_success(self, value):
        self._is_success = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value

    def parse_response_content(self, response_content):
        response = super(AlipayEbppProdmodeAgreementUploadResponse, self).parse_response_content(response_content)
        if 'is_success' in response:
            self.is_success = response['is_success']
        if 'memo' in response:
            self.memo = response['memo']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class GoodsDetailInfo(object):

    def __init__(self):
        self._goods_id = None
        self._goods_name = None
        self._goods_unit = None
        self._quantity = None
        self._unit_price = None

    @property
    def goods_id(self):
        return self._goods_id

    @goods_id.setter
    def goods_id(self, value):
        self._goods_id = value
    @property
    def goods_name(self):
        return self._goods_name

    @goods_name.setter
    def goods_name(self, value):
        self._goods_name = value
    @property
    def goods_unit(self):
        return self._goods_unit

    @goods_unit.setter
    def goods_unit(self, value):
        self._goods_unit = value
    @property
    def quantity(self):
        return self._quantity

    @quantity.setter
    def quantity(self, value):
        self._quantity = value
    @property
    def unit_price(self):
        return self._unit_price

    @unit_price.setter
    def unit_price(self, value):
        self._unit_price = value


    def to_alipay_dict(self):
        params = dict()
        if self.goods_id:
            if hasattr(self.goods_id, 'to_alipay_dict'):
                params['goods_id'] = self.goods_id.to_alipay_dict()
            else:
                params['goods_id'] = self.goods_id
        if self.goods_name:
            if hasattr(self.goods_name, 'to_alipay_dict'):
                params['goods_name'] = self.goods_name.to_alipay_dict()
            else:
                params['goods_name'] = self.goods_name
        if self.goods_unit:
            if hasattr(self.goods_unit, 'to_alipay_dict'):
                params['goods_unit'] = self.goods_unit.to_alipay_dict()
            else:
                params['goods_unit'] = self.goods_unit
        if self.quantity:
            if hasattr(self.quantity, 'to_alipay_dict'):
                params['quantity'] = self.quantity.to_alipay_dict()
            else:
                params['quantity'] = self.quantity
        if self.unit_price:
            if hasattr(self.unit_price, 'to_alipay_dict'):
                params['unit_price'] = self.unit_price.to_alipay_dict()
            else:
                params['unit_price'] = self.unit_price
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = GoodsDetailInfo()
        if 'goods_id' in d:
            o.goods_id = d['goods_id']
        if 'goods_name' in d:
            o.goods_name = d['goods_name']
        if 'goods_unit' in d:
            o.goods_unit = d['goods_unit']
        if 'quantity' in d:
            o.quantity = d['quantity']
        if 'unit_price' in d:
            o.unit_price = d['unit_price']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.GoodsVO import GoodsVO


class KoubeiRetailWmsGoodsBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiRetailWmsGoodsBatchqueryResponse, self).__init__()
        self._goods = None
        self._total_count = None

    @property
    def goods(self):
        return self._goods

    @goods.setter
    def goods(self, value):
        if isinstance(value, list):
            self._goods = list()
            for i in value:
                if isinstance(i, GoodsVO):
                    self._goods.append(i)
                else:
                    self._goods.append(GoodsVO.from_alipay_dict(i))
    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value

    def parse_response_content(self, response_content):
        response = super(KoubeiRetailWmsGoodsBatchqueryResponse, self).parse_response_content(response_content)
        if 'goods' in response:
            self.goods = response['goods']
        if 'total_count' in response:
            self.total_count = response['total_count']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.SceneMarketingContent import SceneMarketingContent


class SceneMarketingContentGroup(object):

    def __init__(self):
        self._data_list = None
        self._group_name = None
        self._summary = None

    @property
    def data_list(self):
        return self._data_list

    @data_list.setter
    def data_list(self, value):
        if isinstance(value, list):
            self._data_list = list()
            for i in value:
                if isinstance(i, SceneMarketingContent):
                    self._data_list.append(i)
                else:
                    self._data_list.append(SceneMarketingContent.from_alipay_dict(i))
    @property
    def group_name(self):
        return self._group_name

    @group_name.setter
    def group_name(self, value):
        self._group_name = value
    @property
    def summary(self):
        return self._summary

    @summary.setter
    def summary(self, value):
        self._summary = value


    def to_alipay_dict(self):
        params = dict()
        if self.data_list:
            if isinstance(self.data_list, list):
                for i in range(0, len(self.data_list)):
                    element = self.data_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.data_list[i] = element.to_alipay_dict()
            if hasattr(self.data_list, 'to_alipay_dict'):
                params['data_list'] = self.data_list.to_alipay_dict()
            else:
                params['data_list'] = self.data_list
        if self.group_name:
            if hasattr(self.group_name, 'to_alipay_dict'):
                params['group_name'] = self.group_name.to_alipay_dict()
            else:
                params['group_name'] = self.group_name
        if self.summary:
            if hasattr(self.summary, 'to_alipay_dict'):
                params['summary'] = self.summary.to_alipay_dict()
            else:
                params['summary'] = self.summary
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SceneMarketingContentGroup()
        if 'data_list' in d:
            o.data_list = d['data_list']
        if 'group_name' in d:
            o.group_name = d['group_name']
        if 'summary' in d:
            o.summary = d['summary']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AccessOrdersFeedBack(object):

    def __init__(self):
        self._error_code = None
        self._error_desc = None
        self._feedback_id = None
        self._order_type = None
        self._out_biz_no = None
        self._success = None

    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_desc(self):
        return self._error_desc

    @error_desc.setter
    def error_desc(self, value):
        self._error_desc = value
    @property
    def feedback_id(self):
        return self._feedback_id

    @feedback_id.setter
    def feedback_id(self, value):
        self._feedback_id = value
    @property
    def order_type(self):
        return self._order_type

    @order_type.setter
    def order_type(self, value):
        self._order_type = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value


    def to_alipay_dict(self):
        params = dict()
        if self.error_code:
            if hasattr(self.error_code, 'to_alipay_dict'):
                params['error_code'] = self.error_code.to_alipay_dict()
            else:
                params['error_code'] = self.error_code
        if self.error_desc:
            if hasattr(self.error_desc, 'to_alipay_dict'):
                params['error_desc'] = self.error_desc.to_alipay_dict()
            else:
                params['error_desc'] = self.error_desc
        if self.feedback_id:
            if hasattr(self.feedback_id, 'to_alipay_dict'):
                params['feedback_id'] = self.feedback_id.to_alipay_dict()
            else:
                params['feedback_id'] = self.feedback_id
        if self.order_type:
            if hasattr(self.order_type, 'to_alipay_dict'):
                params['order_type'] = self.order_type.to_alipay_dict()
            else:
                params['order_type'] = self.order_type
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.success:
            if hasattr(self.success, 'to_alipay_dict'):
                params['success'] = self.success.to_alipay_dict()
            else:
                params['success'] = self.success
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AccessOrdersFeedBack()
        if 'error_code' in d:
            o.error_code = d['error_code']
        if 'error_desc' in d:
            o.error_desc = d['error_desc']
        if 'feedback_id' in d:
            o.feedback_id = d['feedback_id']
        if 'order_type' in d:
            o.order_type = d['order_type']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'success' in d:
            o.success = d['success']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechAiCvUaAsyncIdentifyModel(object):

    def __init__(self):
        self._m_app_id = None
        self._params = None
        self._service_code = None
        self._trace_id = None
        self._uri = None

    @property
    def m_app_id(self):
        return self._m_app_id

    @m_app_id.setter
    def m_app_id(self, value):
        self._m_app_id = value
    @property
    def params(self):
        return self._params

    @params.setter
    def params(self, value):
        self._params = value
    @property
    def service_code(self):
        return self._service_code

    @service_code.setter
    def service_code(self, value):
        self._service_code = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value
    @property
    def uri(self):
        return self._uri

    @uri.setter
    def uri(self, value):
        self._uri = value


    def to_alipay_dict(self):
        params = dict()
        if self.m_app_id:
            if hasattr(self.m_app_id, 'to_alipay_dict'):
                params['m_app_id'] = self.m_app_id.to_alipay_dict()
            else:
                params['m_app_id'] = self.m_app_id
        if self.params:
            if hasattr(self.params, 'to_alipay_dict'):
                params['params'] = self.params.to_alipay_dict()
            else:
                params['params'] = self.params
        if self.service_code:
            if hasattr(self.service_code, 'to_alipay_dict'):
                params['service_code'] = self.service_code.to_alipay_dict()
            else:
                params['service_code'] = self.service_code
        if self.trace_id:
            if hasattr(self.trace_id, 'to_alipay_dict'):
                params['trace_id'] = self.trace_id.to_alipay_dict()
            else:
                params['trace_id'] = self.trace_id
        if self.uri:
            if hasattr(self.uri, 'to_alipay_dict'):
                params['uri'] = self.uri.to_alipay_dict()
            else:
                params['uri'] = self.uri
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechAiCvUaAsyncIdentifyModel()
        if 'm_app_id' in d:
            o.m_app_id = d['m_app_id']
        if 'params' in d:
            o.params = d['params']
        if 'service_code' in d:
            o.service_code = d['service_code']
        if 'trace_id' in d:
            o.trace_id = d['trace_id']
        if 'uri' in d:
            o.uri = d['uri']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniResourceDataQueryModel(object):

    def __init__(self):
        self._plugin_id = None
        self._report_date = None
        self._resource_id = None

    @property
    def plugin_id(self):
        return self._plugin_id

    @plugin_id.setter
    def plugin_id(self, value):
        self._plugin_id = value
    @property
    def report_date(self):
        return self._report_date

    @report_date.setter
    def report_date(self, value):
        self._report_date = value
    @property
    def resource_id(self):
        return self._resource_id

    @resource_id.setter
    def resource_id(self, value):
        self._resource_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.plugin_id:
            if hasattr(self.plugin_id, 'to_alipay_dict'):
                params['plugin_id'] = self.plugin_id.to_alipay_dict()
            else:
                params['plugin_id'] = self.plugin_id
        if self.report_date:
            if hasattr(self.report_date, 'to_alipay_dict'):
                params['report_date'] = self.report_date.to_alipay_dict()
            else:
                params['report_date'] = self.report_date
        if self.resource_id:
            if hasattr(self.resource_id, 'to_alipay_dict'):
                params['resource_id'] = self.resource_id.to_alipay_dict()
            else:
                params['resource_id'] = self.resource_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniResourceDataQueryModel()
        if 'plugin_id' in d:
            o.plugin_id = d['plugin_id']
        if 'report_date' in d:
            o.report_date = d['report_date']
        if 'resource_id' in d:
            o.resource_id = d['resource_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SlmDeviceInfo(object):

    def __init__(self):
        self._brand = None
        self._platform = None
        self._product = None
        self._scope = None
        self._sn = None
        self._support = None

    @property
    def brand(self):
        return self._brand

    @brand.setter
    def brand(self, value):
        self._brand = value
    @property
    def platform(self):
        return self._platform

    @platform.setter
    def platform(self, value):
        self._platform = value
    @property
    def product(self):
        return self._product

    @product.setter
    def product(self, value):
        self._product = value
    @property
    def scope(self):
        return self._scope

    @scope.setter
    def scope(self, value):
        self._scope = value
    @property
    def sn(self):
        return self._sn

    @sn.setter
    def sn(self, value):
        self._sn = value
    @property
    def support(self):
        return self._support

    @support.setter
    def support(self, value):
        self._support = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand:
            if hasattr(self.brand, 'to_alipay_dict'):
                params['brand'] = self.brand.to_alipay_dict()
            else:
                params['brand'] = self.brand
        if self.platform:
            if hasattr(self.platform, 'to_alipay_dict'):
                params['platform'] = self.platform.to_alipay_dict()
            else:
                params['platform'] = self.platform
        if self.product:
            if hasattr(self.product, 'to_alipay_dict'):
                params['product'] = self.product.to_alipay_dict()
            else:
                params['product'] = self.product
        if self.scope:
            if hasattr(self.scope, 'to_alipay_dict'):
                params['scope'] = self.scope.to_alipay_dict()
            else:
                params['scope'] = self.scope
        if self.sn:
            if hasattr(self.sn, 'to_alipay_dict'):
                params['sn'] = self.sn.to_alipay_dict()
            else:
                params['sn'] = self.sn
        if self.support:
            if hasattr(self.support, 'to_alipay_dict'):
                params['support'] = self.support.to_alipay_dict()
            else:
                params['support'] = self.support
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SlmDeviceInfo()
        if 'brand' in d:
            o.brand = d['brand']
        if 'platform' in d:
            o.platform = d['platform']
        if 'product' in d:
            o.product = d['product']
        if 'scope' in d:
            o.scope = d['scope']
        if 'sn' in d:
            o.sn = d['sn']
        if 'support' in d:
            o.support = d['support']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechMorseMarketingSrtaConsultResponse(AlipayResponse):

    def __init__(self):
        super(AnttechMorseMarketingSrtaConsultResponse, self).__init__()
        self._biz_no = None
        self._blind_signed_mobile_sha_256 = None
        self._result_cipher_list = None

    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def blind_signed_mobile_sha_256(self):
        return self._blind_signed_mobile_sha_256

    @blind_signed_mobile_sha_256.setter
    def blind_signed_mobile_sha_256(self, value):
        self._blind_signed_mobile_sha_256 = value
    @property
    def result_cipher_list(self):
        return self._result_cipher_list

    @result_cipher_list.setter
    def result_cipher_list(self, value):
        self._result_cipher_list = value

    def parse_response_content(self, response_content):
        response = super(AnttechMorseMarketingSrtaConsultResponse, self).parse_response_content(response_content)
        if 'biz_no' in response:
            self.biz_no = response['biz_no']
        if 'blind_signed_mobile_sha_256' in response:
            self.blind_signed_mobile_sha_256 = response['blind_signed_mobile_sha_256']
        if 'result_cipher_list' in response:
            self.result_cipher_list = response['result_cipher_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCampaignRuleRulelistQueryModel(object):

    def __init__(self):
        self._mpid = None
        self._pageno = None
        self._pagesize = None

    @property
    def mpid(self):
        return self._mpid

    @mpid.setter
    def mpid(self, value):
        self._mpid = value
    @property
    def pageno(self):
        return self._pageno

    @pageno.setter
    def pageno(self, value):
        self._pageno = value
    @property
    def pagesize(self):
        return self._pagesize

    @pagesize.setter
    def pagesize(self, value):
        self._pagesize = value


    def to_alipay_dict(self):
        params = dict()
        if self.mpid:
            if hasattr(self.mpid, 'to_alipay_dict'):
                params['mpid'] = self.mpid.to_alipay_dict()
            else:
                params['mpid'] = self.mpid
        if self.pageno:
            if hasattr(self.pageno, 'to_alipay_dict'):
                params['pageno'] = self.pageno.to_alipay_dict()
            else:
                params['pageno'] = self.pageno
        if self.pagesize:
            if hasattr(self.pagesize, 'to_alipay_dict'):
                params['pagesize'] = self.pagesize.to_alipay_dict()
            else:
                params['pagesize'] = self.pagesize
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCampaignRuleRulelistQueryModel()
        if 'mpid' in d:
            o.mpid = d['mpid']
        if 'pageno' in d:
            o.pageno = d['pageno']
        if 'pagesize' in d:
            o.pagesize = d['pagesize']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AccountDTO(object):

    def __init__(self):
        self._account_name = None
        self._account_no = None
        self._offical_name = None
        self._offical_number = None

    @property
    def account_name(self):
        return self._account_name

    @account_name.setter
    def account_name(self, value):
        self._account_name = value
    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value
    @property
    def offical_name(self):
        return self._offical_name

    @offical_name.setter
    def offical_name(self, value):
        self._offical_name = value
    @property
    def offical_number(self):
        return self._offical_number

    @offical_number.setter
    def offical_number(self, value):
        self._offical_number = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_name:
            if hasattr(self.account_name, 'to_alipay_dict'):
                params['account_name'] = self.account_name.to_alipay_dict()
            else:
                params['account_name'] = self.account_name
        if self.account_no:
            if hasattr(self.account_no, 'to_alipay_dict'):
                params['account_no'] = self.account_no.to_alipay_dict()
            else:
                params['account_no'] = self.account_no
        if self.offical_name:
            if hasattr(self.offical_name, 'to_alipay_dict'):
                params['offical_name'] = self.offical_name.to_alipay_dict()
            else:
                params['offical_name'] = self.offical_name
        if self.offical_number:
            if hasattr(self.offical_number, 'to_alipay_dict'):
                params['offical_number'] = self.offical_number.to_alipay_dict()
            else:
                params['offical_number'] = self.offical_number
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AccountDTO()
        if 'account_name' in d:
            o.account_name = d['account_name']
        if 'account_no' in d:
            o.account_no = d['account_no']
        if 'offical_name' in d:
            o.offical_name = d['offical_name']
        if 'offical_number' in d:
            o.offical_number = d['offical_number']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AntSignFileRequest import AntSignFileRequest
from alipay.aop.api.domain.AntSignUserInfoRequest import AntSignUserInfoRequest


class AntSignTaskRequest(object):

    def __init__(self):
        self._ant_sign_file_request_list = None
        self._ant_sign_user_info_request_list = None
        self._description = None
        self._related_business = None
        self._sub_biz_no = None

    @property
    def ant_sign_file_request_list(self):
        return self._ant_sign_file_request_list

    @ant_sign_file_request_list.setter
    def ant_sign_file_request_list(self, value):
        if isinstance(value, list):
            self._ant_sign_file_request_list = list()
            for i in value:
                if isinstance(i, AntSignFileRequest):
                    self._ant_sign_file_request_list.append(i)
                else:
                    self._ant_sign_file_request_list.append(AntSignFileRequest.from_alipay_dict(i))
    @property
    def ant_sign_user_info_request_list(self):
        return self._ant_sign_user_info_request_list

    @ant_sign_user_info_request_list.setter
    def ant_sign_user_info_request_list(self, value):
        if isinstance(value, list):
            self._ant_sign_user_info_request_list = list()
            for i in value:
                if isinstance(i, AntSignUserInfoRequest):
                    self._ant_sign_user_info_request_list.append(i)
                else:
                    self._ant_sign_user_info_request_list.append(AntSignUserInfoRequest.from_alipay_dict(i))
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def related_business(self):
        return self._related_business

    @related_business.setter
    def related_business(self, value):
        self._related_business = value
    @property
    def sub_biz_no(self):
        return self._sub_biz_no

    @sub_biz_no.setter
    def sub_biz_no(self, value):
        self._sub_biz_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.ant_sign_file_request_list:
            if isinstance(self.ant_sign_file_request_list, list):
                for i in range(0, len(self.ant_sign_file_request_list)):
                    element = self.ant_sign_file_request_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ant_sign_file_request_list[i] = element.to_alipay_dict()
            if hasattr(self.ant_sign_file_request_list, 'to_alipay_dict'):
                params['ant_sign_file_request_list'] = self.ant_sign_file_request_list.to_alipay_dict()
            else:
                params['ant_sign_file_request_list'] = self.ant_sign_file_request_list
        if self.ant_sign_user_info_request_list:
            if isinstance(self.ant_sign_user_info_request_list, list):
                for i in range(0, len(self.ant_sign_user_info_request_list)):
                    element = self.ant_sign_user_info_request_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ant_sign_user_info_request_list[i] = element.to_alipay_dict()
            if hasattr(self.ant_sign_user_info_request_list, 'to_alipay_dict'):
                params['ant_sign_user_info_request_list'] = self.ant_sign_user_info_request_list.to_alipay_dict()
            else:
                params['ant_sign_user_info_request_list'] = self.ant_sign_user_info_request_list
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.related_business:
            if hasattr(self.related_business, 'to_alipay_dict'):
                params['related_business'] = self.related_business.to_alipay_dict()
            else:
                params['related_business'] = self.related_business
        if self.sub_biz_no:
            if hasattr(self.sub_biz_no, 'to_alipay_dict'):
                params['sub_biz_no'] = self.sub_biz_no.to_alipay_dict()
            else:
                params['sub_biz_no'] = self.sub_biz_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntSignTaskRequest()
        if 'ant_sign_file_request_list' in d:
            o.ant_sign_file_request_list = d['ant_sign_file_request_list']
        if 'ant_sign_user_info_request_list' in d:
            o.ant_sign_user_info_request_list = d['ant_sign_user_info_request_list']
        if 'description' in d:
            o.description = d['description']
        if 'related_business' in d:
            o.related_business = d['related_business']
        if 'sub_biz_no' in d:
            o.sub_biz_no = d['sub_biz_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataBillBailQueryModel(object):

    def __init__(self):
        self._bail_type = None
        self._biz_orig_no = None
        self._end_time = None
        self._start_time = None
        self._trans_log_id = None

    @property
    def bail_type(self):
        return self._bail_type

    @bail_type.setter
    def bail_type(self, value):
        self._bail_type = value
    @property
    def biz_orig_no(self):
        return self._biz_orig_no

    @biz_orig_no.setter
    def biz_orig_no(self, value):
        self._biz_orig_no = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def trans_log_id(self):
        return self._trans_log_id

    @trans_log_id.setter
    def trans_log_id(self, value):
        self._trans_log_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.bail_type:
            if hasattr(self.bail_type, 'to_alipay_dict'):
                params['bail_type'] = self.bail_type.to_alipay_dict()
            else:
                params['bail_type'] = self.bail_type
        if self.biz_orig_no:
            if hasattr(self.biz_orig_no, 'to_alipay_dict'):
                params['biz_orig_no'] = self.biz_orig_no.to_alipay_dict()
            else:
                params['biz_orig_no'] = self.biz_orig_no
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.trans_log_id:
            if hasattr(self.trans_log_id, 'to_alipay_dict'):
                params['trans_log_id'] = self.trans_log_id.to_alipay_dict()
            else:
                params['trans_log_id'] = self.trans_log_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataBillBailQueryModel()
        if 'bail_type' in d:
            o.bail_type = d['bail_type']
        if 'biz_orig_no' in d:
            o.biz_orig_no = d['biz_orig_no']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'trans_log_id' in d:
            o.trans_log_id = d['trans_log_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbAdvertCommissionClausePercentageResponse(object):

    def __init__(self):
        self._commission_rate = None
        self._max_limit = None

    @property
    def commission_rate(self):
        return self._commission_rate

    @commission_rate.setter
    def commission_rate(self, value):
        self._commission_rate = value
    @property
    def max_limit(self):
        return self._max_limit

    @max_limit.setter
    def max_limit(self, value):
        self._max_limit = value


    def to_alipay_dict(self):
        params = dict()
        if self.commission_rate:
            if hasattr(self.commission_rate, 'to_alipay_dict'):
                params['commission_rate'] = self.commission_rate.to_alipay_dict()
            else:
                params['commission_rate'] = self.commission_rate
        if self.max_limit:
            if hasattr(self.max_limit, 'to_alipay_dict'):
                params['max_limit'] = self.max_limit.to_alipay_dict()
            else:
                params['max_limit'] = self.max_limit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbAdvertCommissionClausePercentageResponse()
        if 'commission_rate' in d:
            o.commission_rate = d['commission_rate']
        if 'max_limit' in d:
            o.max_limit = d['max_limit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlCollectionReceiveBaseInfoDTO(object):

    def __init__(self):
        self._collection_title = None
        self._memo = None
        self._order_id = None
        self._source_sys = None
        self._template_id = None

    @property
    def collection_title(self):
        return self._collection_title

    @collection_title.setter
    def collection_title(self, value):
        self._collection_title = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def source_sys(self):
        return self._source_sys

    @source_sys.setter
    def source_sys(self, value):
        self._source_sys = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.collection_title:
            if hasattr(self.collection_title, 'to_alipay_dict'):
                params['collection_title'] = self.collection_title.to_alipay_dict()
            else:
                params['collection_title'] = self.collection_title
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.source_sys:
            if hasattr(self.source_sys, 'to_alipay_dict'):
                params['source_sys'] = self.source_sys.to_alipay_dict()
            else:
                params['source_sys'] = self.source_sys
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlCollectionReceiveBaseInfoDTO()
        if 'collection_title' in d:
            o.collection_title = d['collection_title']
        if 'memo' in d:
            o.memo = d['memo']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'source_sys' in d:
            o.source_sys = d['source_sys']
        if 'template_id' in d:
            o.template_id = d['template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TrendQueryRequest import TrendQueryRequest


class AlipayMerchantQipanTrendQueryModel(object):

    def __init__(self):
        self._index_key = None
        self._request_params = None

    @property
    def index_key(self):
        return self._index_key

    @index_key.setter
    def index_key(self, value):
        self._index_key = value
    @property
    def request_params(self):
        return self._request_params

    @request_params.setter
    def request_params(self, value):
        if isinstance(value, TrendQueryRequest):
            self._request_params = value
        else:
            self._request_params = TrendQueryRequest.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.index_key:
            if hasattr(self.index_key, 'to_alipay_dict'):
                params['index_key'] = self.index_key.to_alipay_dict()
            else:
                params['index_key'] = self.index_key
        if self.request_params:
            if hasattr(self.request_params, 'to_alipay_dict'):
                params['request_params'] = self.request_params.to_alipay_dict()
            else:
                params['request_params'] = self.request_params
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantQipanTrendQueryModel()
        if 'index_key' in d:
            o.index_key = d['index_key']
        if 'request_params' in d:
            o.request_params = d['request_params']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateSchoolserviceModifyModel(object):

    def __init__(self):
        self._content_id = None
        self._name = None
        self._out_service_id = None
        self._school_name = None
        self._service_app_id = None
        self._service_id = None
        self._source_type = None
        self._url = None

    @property
    def content_id(self):
        return self._content_id

    @content_id.setter
    def content_id(self, value):
        self._content_id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def out_service_id(self):
        return self._out_service_id

    @out_service_id.setter
    def out_service_id(self, value):
        self._out_service_id = value
    @property
    def school_name(self):
        return self._school_name

    @school_name.setter
    def school_name(self, value):
        self._school_name = value
    @property
    def service_app_id(self):
        return self._service_app_id

    @service_app_id.setter
    def service_app_id(self, value):
        self._service_app_id = value
    @property
    def service_id(self):
        return self._service_id

    @service_id.setter
    def service_id(self, value):
        self._service_id = value
    @property
    def source_type(self):
        return self._source_type

    @source_type.setter
    def source_type(self, value):
        self._source_type = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value


    def to_alipay_dict(self):
        params = dict()
        if self.content_id:
            if hasattr(self.content_id, 'to_alipay_dict'):
                params['content_id'] = self.content_id.to_alipay_dict()
            else:
                params['content_id'] = self.content_id
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.out_service_id:
            if hasattr(self.out_service_id, 'to_alipay_dict'):
                params['out_service_id'] = self.out_service_id.to_alipay_dict()
            else:
                params['out_service_id'] = self.out_service_id
        if self.school_name:
            if hasattr(self.school_name, 'to_alipay_dict'):
                params['school_name'] = self.school_name.to_alipay_dict()
            else:
                params['school_name'] = self.school_name
        if self.service_app_id:
            if hasattr(self.service_app_id, 'to_alipay_dict'):
                params['service_app_id'] = self.service_app_id.to_alipay_dict()
            else:
                params['service_app_id'] = self.service_app_id
        if self.service_id:
            if hasattr(self.service_id, 'to_alipay_dict'):
                params['service_id'] = self.service_id.to_alipay_dict()
            else:
                params['service_id'] = self.service_id
        if self.source_type:
            if hasattr(self.source_type, 'to_alipay_dict'):
                params['source_type'] = self.source_type.to_alipay_dict()
            else:
                params['source_type'] = self.source_type
        if self.url:
            if hasattr(self.url, 'to_alipay_dict'):
                params['url'] = self.url.to_alipay_dict()
            else:
                params['url'] = self.url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateSchoolserviceModifyModel()
        if 'content_id' in d:
            o.content_id = d['content_id']
        if 'name' in d:
            o.name = d['name']
        if 'out_service_id' in d:
            o.out_service_id = d['out_service_id']
        if 'school_name' in d:
            o.school_name = d['school_name']
        if 'service_app_id' in d:
            o.service_app_id = d['service_app_id']
        if 'service_id' in d:
            o.service_id = d['service_id']
        if 'source_type' in d:
            o.source_type = d['source_type']
        if 'url' in d:
            o.url = d['url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditPayafteruseCreditbizorderOrderModel(object):

    def __init__(self):
        self._amount_type = None
        self._body = None
        self._category_id = None
        self._credit_agreement_id = None
        self._extend_params = None
        self._order_amount = None
        self._out_order_no = None
        self._product_code = None
        self._subject = None

    @property
    def amount_type(self):
        return self._amount_type

    @amount_type.setter
    def amount_type(self, value):
        self._amount_type = value
    @property
    def body(self):
        return self._body

    @body.setter
    def body(self, value):
        self._body = value
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def credit_agreement_id(self):
        return self._credit_agreement_id

    @credit_agreement_id.setter
    def credit_agreement_id(self, value):
        self._credit_agreement_id = value
    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        self._extend_params = value
    @property
    def order_amount(self):
        return self._order_amount

    @order_amount.setter
    def order_amount(self, value):
        self._order_amount = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount_type:
            if hasattr(self.amount_type, 'to_alipay_dict'):
                params['amount_type'] = self.amount_type.to_alipay_dict()
            else:
                params['amount_type'] = self.amount_type
        if self.body:
            if hasattr(self.body, 'to_alipay_dict'):
                params['body'] = self.body.to_alipay_dict()
            else:
                params['body'] = self.body
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.credit_agreement_id:
            if hasattr(self.credit_agreement_id, 'to_alipay_dict'):
                params['credit_agreement_id'] = self.credit_agreement_id.to_alipay_dict()
            else:
                params['credit_agreement_id'] = self.credit_agreement_id
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.order_amount:
            if hasattr(self.order_amount, 'to_alipay_dict'):
                params['order_amount'] = self.order_amount.to_alipay_dict()
            else:
                params['order_amount'] = self.order_amount
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditPayafteruseCreditbizorderOrderModel()
        if 'amount_type' in d:
            o.amount_type = d['amount_type']
        if 'body' in d:
            o.body = d['body']
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'credit_agreement_id' in d:
            o.credit_agreement_id = d['credit_agreement_id']
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'order_amount' in d:
            o.order_amount = d['order_amount']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'subject' in d:
            o.subject = d['subject']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PageInfoDTO import PageInfoDTO


class DatadigitalFincloudFinsaasDesignPageGetResponse(AlipayResponse):

    def __init__(self):
        super(DatadigitalFincloudFinsaasDesignPageGetResponse, self).__init__()
        self._page_code = None
        self._page_info = None

    @property
    def page_code(self):
        return self._page_code

    @page_code.setter
    def page_code(self, value):
        self._page_code = value
    @property
    def page_info(self):
        return self._page_info

    @page_info.setter
    def page_info(self, value):
        if isinstance(value, PageInfoDTO):
            self._page_info = value
        else:
            self._page_info = PageInfoDTO.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(DatadigitalFincloudFinsaasDesignPageGetResponse, self).parse_response_content(response_content)
        if 'page_code' in response:
            self.page_code = response['page_code']
        if 'page_info' in response:
            self.page_info = response['page_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserFamilyArchiveInitializeModel(object):

    def __init__(self):
        self._archive_id_list = None
        self._max_archives_cnt = None
        self._min_archives_cnt = None
        self._out_biz_no = None
        self._redirect_uri = None
        self._template_id = None

    @property
    def archive_id_list(self):
        return self._archive_id_list

    @archive_id_list.setter
    def archive_id_list(self, value):
        if isinstance(value, list):
            self._archive_id_list = list()
            for i in value:
                self._archive_id_list.append(i)
    @property
    def max_archives_cnt(self):
        return self._max_archives_cnt

    @max_archives_cnt.setter
    def max_archives_cnt(self, value):
        self._max_archives_cnt = value
    @property
    def min_archives_cnt(self):
        return self._min_archives_cnt

    @min_archives_cnt.setter
    def min_archives_cnt(self, value):
        self._min_archives_cnt = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def redirect_uri(self):
        return self._redirect_uri

    @redirect_uri.setter
    def redirect_uri(self, value):
        self._redirect_uri = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.archive_id_list:
            if isinstance(self.archive_id_list, list):
                for i in range(0, len(self.archive_id_list)):
                    element = self.archive_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.archive_id_list[i] = element.to_alipay_dict()
            if hasattr(self.archive_id_list, 'to_alipay_dict'):
                params['archive_id_list'] = self.archive_id_list.to_alipay_dict()
            else:
                params['archive_id_list'] = self.archive_id_list
        if self.max_archives_cnt:
            if hasattr(self.max_archives_cnt, 'to_alipay_dict'):
                params['max_archives_cnt'] = self.max_archives_cnt.to_alipay_dict()
            else:
                params['max_archives_cnt'] = self.max_archives_cnt
        if self.min_archives_cnt:
            if hasattr(self.min_archives_cnt, 'to_alipay_dict'):
                params['min_archives_cnt'] = self.min_archives_cnt.to_alipay_dict()
            else:
                params['min_archives_cnt'] = self.min_archives_cnt
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.redirect_uri:
            if hasattr(self.redirect_uri, 'to_alipay_dict'):
                params['redirect_uri'] = self.redirect_uri.to_alipay_dict()
            else:
                params['redirect_uri'] = self.redirect_uri
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserFamilyArchiveInitializeModel()
        if 'archive_id_list' in d:
            o.archive_id_list = d['archive_id_list']
        if 'max_archives_cnt' in d:
            o.max_archives_cnt = d['max_archives_cnt']
        if 'min_archives_cnt' in d:
            o.min_archives_cnt = d['min_archives_cnt']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'redirect_uri' in d:
            o.redirect_uri = d['redirect_uri']
        if 'template_id' in d:
            o.template_id = d['template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringDishGroupQueryModel(object):

    def __init__(self):
        self._group_id = None
        self._merchant_id = None
        self._status = None

    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value


    def to_alipay_dict(self):
        params = dict()
        if self.group_id:
            if hasattr(self.group_id, 'to_alipay_dict'):
                params['group_id'] = self.group_id.to_alipay_dict()
            else:
                params['group_id'] = self.group_id
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringDishGroupQueryModel()
        if 'group_id' in d:
            o.group_id = d['group_id']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'status' in d:
            o.status = d['status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TuitionOrderExtendParam import TuitionOrderExtendParam


class AlipayCommerceEducateTuitioncodePagedataSendModel(object):

    def __init__(self):
        self._alias_name = None
        self._course_end_month = None
        self._course_name = None
        self._course_start_month = None
        self._ext_info = None
        self._ext_param = None
        self._logo = None
        self._out_biz_no = None
        self._out_order_no = None
        self._pay_amount = None
        self._period = None
        self._period_type = None
        self._remark = None
        self._smid = None
        self._user_display_name = None

    @property
    def alias_name(self):
        return self._alias_name

    @alias_name.setter
    def alias_name(self, value):
        self._alias_name = value
    @property
    def course_end_month(self):
        return self._course_end_month

    @course_end_month.setter
    def course_end_month(self, value):
        self._course_end_month = value
    @property
    def course_name(self):
        return self._course_name

    @course_name.setter
    def course_name(self, value):
        self._course_name = value
    @property
    def course_start_month(self):
        return self._course_start_month

    @course_start_month.setter
    def course_start_month(self, value):
        self._course_start_month = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        if isinstance(value, TuitionOrderExtendParam):
            self._ext_param = value
        else:
            self._ext_param = TuitionOrderExtendParam.from_alipay_dict(value)
    @property
    def logo(self):
        return self._logo

    @logo.setter
    def logo(self, value):
        self._logo = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def out_order_no(self):
        return self._out_order_no

    @out_order_no.setter
    def out_order_no(self, value):
        self._out_order_no = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def period(self):
        return self._period

    @period.setter
    def period(self, value):
        self._period = value
    @property
    def period_type(self):
        return self._period_type

    @period_type.setter
    def period_type(self, value):
        self._period_type = value
    @property
    def remark(self):
        return self._remark

    @remark.setter
    def remark(self, value):
        self._remark = value
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value
    @property
    def user_display_name(self):
        return self._user_display_name

    @user_display_name.setter
    def user_display_name(self, value):
        self._user_display_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.alias_name:
            if hasattr(self.alias_name, 'to_alipay_dict'):
                params['alias_name'] = self.alias_name.to_alipay_dict()
            else:
                params['alias_name'] = self.alias_name
        if self.course_end_month:
            if hasattr(self.course_end_month, 'to_alipay_dict'):
                params['course_end_month'] = self.course_end_month.to_alipay_dict()
            else:
                params['course_end_month'] = self.course_end_month
        if self.course_name:
            if hasattr(self.course_name, 'to_alipay_dict'):
                params['course_name'] = self.course_name.to_alipay_dict()
            else:
                params['course_name'] = self.course_name
        if self.course_start_month:
            if hasattr(self.course_start_month, 'to_alipay_dict'):
                params['course_start_month'] = self.course_start_month.to_alipay_dict()
            else:
                params['course_start_month'] = self.course_start_month
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.ext_param:
            if hasattr(self.ext_param, 'to_alipay_dict'):
                params['ext_param'] = self.ext_param.to_alipay_dict()
            else:
                params['ext_param'] = self.ext_param
        if self.logo:
            if hasattr(self.logo, 'to_alipay_dict'):
                params['logo'] = self.logo.to_alipay_dict()
            else:
                params['logo'] = self.logo
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.out_order_no:
            if hasattr(self.out_order_no, 'to_alipay_dict'):
                params['out_order_no'] = self.out_order_no.to_alipay_dict()
            else:
                params['out_order_no'] = self.out_order_no
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = self.pay_amount.to_alipay_dict()
            else:
                params['pay_amount'] = self.pay_amount
        if self.period:
            if hasattr(self.period, 'to_alipay_dict'):
                params['period'] = self.period.to_alipay_dict()
            else:
                params['period'] = self.period
        if self.period_type:
            if hasattr(self.period_type, 'to_alipay_dict'):
                params['period_type'] = self.period_type.to_alipay_dict()
            else:
                params['period_type'] = self.period_type
        if self.remark:
            if hasattr(self.remark, 'to_alipay_dict'):
                params['remark'] = self.remark.to_alipay_dict()
            else:
                params['remark'] = self.remark
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        if self.user_display_name:
            if hasattr(self.user_display_name, 'to_alipay_dict'):
                params['user_display_name'] = self.user_display_name.to_alipay_dict()
            else:
                params['user_display_name'] = self.user_display_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateTuitioncodePagedataSendModel()
        if 'alias_name' in d:
            o.alias_name = d['alias_name']
        if 'course_end_month' in d:
            o.course_end_month = d['course_end_month']
        if 'course_name' in d:
            o.course_name = d['course_name']
        if 'course_start_month' in d:
            o.course_start_month = d['course_start_month']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'ext_param' in d:
            o.ext_param = d['ext_param']
        if 'logo' in d:
            o.logo = d['logo']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'out_order_no' in d:
            o.out_order_no = d['out_order_no']
        if 'pay_amount' in d:
            o.pay_amount = d['pay_amount']
        if 'period' in d:
            o.period = d['period']
        if 'period_type' in d:
            o.period_type = d['period_type']
        if 'remark' in d:
            o.remark = d['remark']
        if 'smid' in d:
            o.smid = d['smid']
        if 'user_display_name' in d:
            o.user_display_name = d['user_display_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserFamilyShareAuthCheckModel(object):

    def __init__(self):
        self._resource_id = None
        self._scene_id = None
        self._target_biz_user_id = None
        self._target_user_biz_source = None
        self._user_id = None

    @property
    def resource_id(self):
        return self._resource_id

    @resource_id.setter
    def resource_id(self, value):
        self._resource_id = value
    @property
    def scene_id(self):
        return self._scene_id

    @scene_id.setter
    def scene_id(self, value):
        self._scene_id = value
    @property
    def target_biz_user_id(self):
        return self._target_biz_user_id

    @target_biz_user_id.setter
    def target_biz_user_id(self, value):
        self._target_biz_user_id = value
    @property
    def target_user_biz_source(self):
        return self._target_user_biz_source

    @target_user_biz_source.setter
    def target_user_biz_source(self, value):
        self._target_user_biz_source = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.resource_id:
            if hasattr(self.resource_id, 'to_alipay_dict'):
                params['resource_id'] = self.resource_id.to_alipay_dict()
            else:
                params['resource_id'] = self.resource_id
        if self.scene_id:
            if hasattr(self.scene_id, 'to_alipay_dict'):
                params['scene_id'] = self.scene_id.to_alipay_dict()
            else:
                params['scene_id'] = self.scene_id
        if self.target_biz_user_id:
            if hasattr(self.target_biz_user_id, 'to_alipay_dict'):
                params['target_biz_user_id'] = self.target_biz_user_id.to_alipay_dict()
            else:
                params['target_biz_user_id'] = self.target_biz_user_id
        if self.target_user_biz_source:
            if hasattr(self.target_user_biz_source, 'to_alipay_dict'):
                params['target_user_biz_source'] = self.target_user_biz_source.to_alipay_dict()
            else:
                params['target_user_biz_source'] = self.target_user_biz_source
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserFamilyShareAuthCheckModel()
        if 'resource_id' in d:
            o.resource_id = d['resource_id']
        if 'scene_id' in d:
            o.scene_id = d['scene_id']
        if 'target_biz_user_id' in d:
            o.target_biz_user_id = d['target_biz_user_id']
        if 'target_user_biz_source' in d:
            o.target_user_biz_source = d['target_user_biz_source']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ShopReportProgressInfo(object):

    def __init__(self):
        self._current_stage = None
        self._current_stage_status = None
        self._description = None
        self._report_result = None
        self._shop_id = None

    @property
    def current_stage(self):
        return self._current_stage

    @current_stage.setter
    def current_stage(self, value):
        self._current_stage = value
    @property
    def current_stage_status(self):
        return self._current_stage_status

    @current_stage_status.setter
    def current_stage_status(self, value):
        self._current_stage_status = value
    @property
    def description(self):
        return self._description

    @description.setter
    def description(self, value):
        self._description = value
    @property
    def report_result(self):
        return self._report_result

    @report_result.setter
    def report_result(self, value):
        self._report_result = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.current_stage:
            if hasattr(self.current_stage, 'to_alipay_dict'):
                params['current_stage'] = self.current_stage.to_alipay_dict()
            else:
                params['current_stage'] = self.current_stage
        if self.current_stage_status:
            if hasattr(self.current_stage_status, 'to_alipay_dict'):
                params['current_stage_status'] = self.current_stage_status.to_alipay_dict()
            else:
                params['current_stage_status'] = self.current_stage_status
        if self.description:
            if hasattr(self.description, 'to_alipay_dict'):
                params['description'] = self.description.to_alipay_dict()
            else:
                params['description'] = self.description
        if self.report_result:
            if hasattr(self.report_result, 'to_alipay_dict'):
                params['report_result'] = self.report_result.to_alipay_dict()
            else:
                params['report_result'] = self.report_result
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ShopReportProgressInfo()
        if 'current_stage' in d:
            o.current_stage = d['current_stage']
        if 'current_stage_status' in d:
            o.current_stage_status = d['current_stage_status']
        if 'description' in d:
            o.description = d['description']
        if 'report_result' in d:
            o.report_result = d['report_result']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.EnergyQueryRsp import EnergyQueryRsp


class AlipayEcoActivityRecycleQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoActivityRecycleQueryResponse, self).__init__()
        self._energy_list = None

    @property
    def energy_list(self):
        return self._energy_list

    @energy_list.setter
    def energy_list(self, value):
        if isinstance(value, list):
            self._energy_list = list()
            for i in value:
                if isinstance(i, EnergyQueryRsp):
                    self._energy_list.append(i)
                else:
                    self._energy_list.append(EnergyQueryRsp.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayEcoActivityRecycleQueryResponse, self).parse_response_content(response_content)
        if 'energy_list' in response:
            self.energy_list = response['energy_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SubServiceKeyWordInfo import SubServiceKeyWordInfo


class AlipayOpenSearchSubservicekeywordBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenSearchSubservicekeywordBatchqueryResponse, self).__init__()
        self._page_number = None
        self._page_size = None
        self._subservice_keyword_info = None
        self._total_count = None
        self._total_page_count = None

    @property
    def page_number(self):
        return self._page_number

    @page_number.setter
    def page_number(self, value):
        self._page_number = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def subservice_keyword_info(self):
        return self._subservice_keyword_info

    @subservice_keyword_info.setter
    def subservice_keyword_info(self, value):
        if isinstance(value, list):
            self._subservice_keyword_info = list()
            for i in value:
                if isinstance(i, SubServiceKeyWordInfo):
                    self._subservice_keyword_info.append(i)
                else:
                    self._subservice_keyword_info.append(SubServiceKeyWordInfo.from_alipay_dict(i))
    @property
    def total_count(self):
        return self._total_count

    @total_count.setter
    def total_count(self, value):
        self._total_count = value
    @property
    def total_page_count(self):
        return self._total_page_count

    @total_page_count.setter
    def total_page_count(self, value):
        self._total_page_count = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenSearchSubservicekeywordBatchqueryResponse, self).parse_response_content(response_content)
        if 'page_number' in response:
            self.page_number = response['page_number']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'subservice_keyword_info' in response:
            self.subservice_keyword_info = response['subservice_keyword_info']
        if 'total_count' in response:
            self.total_count = response['total_count']
        if 'total_page_count' in response:
            self.total_page_count = response['total_page_count']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class XXXXsdasdasd(object):

    def __init__(self):
        self._wasfdasdf = None

    @property
    def wasfdasdf(self):
        return self._wasfdasdf

    @wasfdasdf.setter
    def wasfdasdf(self, value):
        self._wasfdasdf = value


    def to_alipay_dict(self):
        params = dict()
        if self.wasfdasdf:
            if hasattr(self.wasfdasdf, 'to_alipay_dict'):
                params['wasfdasdf'] = self.wasfdasdf.to_alipay_dict()
            else:
                params['wasfdasdf'] = self.wasfdasdf
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = XXXXsdasdasd()
        if 'wasfdasdf' in d:
            o.wasfdasdf = d['wasfdasdf']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingToolXuanyitestQueryModel(object):

    def __init__(self):
        self._ssss = None
        self._xxx = None

    @property
    def ssss(self):
        return self._ssss

    @ssss.setter
    def ssss(self, value):
        self._ssss = value
    @property
    def xxx(self):
        return self._xxx

    @xxx.setter
    def xxx(self, value):
        self._xxx = value


    def to_alipay_dict(self):
        params = dict()
        if self.ssss:
            if hasattr(self.ssss, 'to_alipay_dict'):
                params['ssss'] = self.ssss.to_alipay_dict()
            else:
                params['ssss'] = self.ssss
        if self.xxx:
            if hasattr(self.xxx, 'to_alipay_dict'):
                params['xxx'] = self.xxx.to_alipay_dict()
            else:
                params['xxx'] = self.xxx
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingToolXuanyitestQueryModel()
        if 'ssss' in d:
            o.ssss = d['ssss']
        if 'xxx' in d:
            o.xxx = d['xxx']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.PageVisitDataResponse import PageVisitDataResponse


class AlipayOpenMiniDataPageQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniDataPageQueryResponse, self).__init__()
        self._page_visit_data_list_response = None

    @property
    def page_visit_data_list_response(self):
        return self._page_visit_data_list_response

    @page_visit_data_list_response.setter
    def page_visit_data_list_response(self, value):
        if isinstance(value, list):
            self._page_visit_data_list_response = list()
            for i in value:
                if isinstance(i, PageVisitDataResponse):
                    self._page_visit_data_list_response.append(i)
                else:
                    self._page_visit_data_list_response.append(PageVisitDataResponse.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniDataPageQueryResponse, self).parse_response_content(response_content)
        if 'page_visit_data_list_response' in response:
            self.page_visit_data_list_response = response['page_visit_data_list_response']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PageTemplateParamInfoDTO import PageTemplateParamInfoDTO


class PageTemplateInfoDTO(object):

    def __init__(self):
        self._code = None
        self._creator_id = None
        self._creator_name = None
        self._current_version = None
        self._edit_version = None
        self._gmt_create = None
        self._gmt_create_code = None
        self._gmt_modified = None
        self._id = None
        self._modifier_id = None
        self._modifier_name = None
        self._name = None
        self._param_template_list = None
        self._picture_url = None
        self._preview_url = None
        self._resolve_code = None
        self._run_version = None
        self._type = None

    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def creator_id(self):
        return self._creator_id

    @creator_id.setter
    def creator_id(self, value):
        self._creator_id = value
    @property
    def creator_name(self):
        return self._creator_name

    @creator_name.setter
    def creator_name(self, value):
        self._creator_name = value
    @property
    def current_version(self):
        return self._current_version

    @current_version.setter
    def current_version(self, value):
        self._current_version = value
    @property
    def edit_version(self):
        return self._edit_version

    @edit_version.setter
    def edit_version(self, value):
        self._edit_version = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_create_code(self):
        return self._gmt_create_code

    @gmt_create_code.setter
    def gmt_create_code(self, value):
        self._gmt_create_code = value
    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def modifier_id(self):
        return self._modifier_id

    @modifier_id.setter
    def modifier_id(self, value):
        self._modifier_id = value
    @property
    def modifier_name(self):
        return self._modifier_name

    @modifier_name.setter
    def modifier_name(self, value):
        self._modifier_name = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def param_template_list(self):
        return self._param_template_list

    @param_template_list.setter
    def param_template_list(self, value):
        if isinstance(value, list):
            self._param_template_list = list()
            for i in value:
                if isinstance(i, PageTemplateParamInfoDTO):
                    self._param_template_list.append(i)
                else:
                    self._param_template_list.append(PageTemplateParamInfoDTO.from_alipay_dict(i))
    @property
    def picture_url(self):
        return self._picture_url

    @picture_url.setter
    def picture_url(self, value):
        self._picture_url = value
    @property
    def preview_url(self):
        return self._preview_url

    @preview_url.setter
    def preview_url(self, value):
        self._preview_url = value
    @property
    def resolve_code(self):
        return self._resolve_code

    @resolve_code.setter
    def resolve_code(self, value):
        self._resolve_code = value
    @property
    def run_version(self):
        return self._run_version

    @run_version.setter
    def run_version(self, value):
        self._run_version = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.code:
            if hasattr(self.code, 'to_alipay_dict'):
                params['code'] = self.code.to_alipay_dict()
            else:
                params['code'] = self.code
        if self.creator_id:
            if hasattr(self.creator_id, 'to_alipay_dict'):
                params['creator_id'] = self.creator_id.to_alipay_dict()
            else:
                params['creator_id'] = self.creator_id
        if self.creator_name:
            if hasattr(self.creator_name, 'to_alipay_dict'):
                params['creator_name'] = self.creator_name.to_alipay_dict()
            else:
                params['creator_name'] = self.creator_name
        if self.current_version:
            if hasattr(self.current_version, 'to_alipay_dict'):
                params['current_version'] = self.current_version.to_alipay_dict()
            else:
                params['current_version'] = self.current_version
        if self.edit_version:
            if hasattr(self.edit_version, 'to_alipay_dict'):
                params['edit_version'] = self.edit_version.to_alipay_dict()
            else:
                params['edit_version'] = self.edit_version
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_create_code:
            if hasattr(self.gmt_create_code, 'to_alipay_dict'):
                params['gmt_create_code'] = self.gmt_create_code.to_alipay_dict()
            else:
                params['gmt_create_code'] = self.gmt_create_code
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.modifier_id:
            if hasattr(self.modifier_id, 'to_alipay_dict'):
                params['modifier_id'] = self.modifier_id.to_alipay_dict()
            else:
                params['modifier_id'] = self.modifier_id
        if self.modifier_name:
            if hasattr(self.modifier_name, 'to_alipay_dict'):
                params['modifier_name'] = self.modifier_name.to_alipay_dict()
            else:
                params['modifier_name'] = self.modifier_name
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.param_template_list:
            if isinstance(self.param_template_list, list):
                for i in range(0, len(self.param_template_list)):
                    element = self.param_template_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.param_template_list[i] = element.to_alipay_dict()
            if hasattr(self.param_template_list, 'to_alipay_dict'):
                params['param_template_list'] = self.param_template_list.to_alipay_dict()
            else:
                params['param_template_list'] = self.param_template_list
        if self.picture_url:
            if hasattr(self.picture_url, 'to_alipay_dict'):
                params['picture_url'] = self.picture_url.to_alipay_dict()
            else:
                params['picture_url'] = self.picture_url
        if self.preview_url:
            if hasattr(self.preview_url, 'to_alipay_dict'):
                params['preview_url'] = self.preview_url.to_alipay_dict()
            else:
                params['preview_url'] = self.preview_url
        if self.resolve_code:
            if hasattr(self.resolve_code, 'to_alipay_dict'):
                params['resolve_code'] = self.resolve_code.to_alipay_dict()
            else:
                params['resolve_code'] = self.resolve_code
        if self.run_version:
            if hasattr(self.run_version, 'to_alipay_dict'):
                params['run_version'] = self.run_version.to_alipay_dict()
            else:
                params['run_version'] = self.run_version
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PageTemplateInfoDTO()
        if 'code' in d:
            o.code = d['code']
        if 'creator_id' in d:
            o.creator_id = d['creator_id']
        if 'creator_name' in d:
            o.creator_name = d['creator_name']
        if 'current_version' in d:
            o.current_version = d['current_version']
        if 'edit_version' in d:
            o.edit_version = d['edit_version']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_create_code' in d:
            o.gmt_create_code = d['gmt_create_code']
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'id' in d:
            o.id = d['id']
        if 'modifier_id' in d:
            o.modifier_id = d['modifier_id']
        if 'modifier_name' in d:
            o.modifier_name = d['modifier_name']
        if 'name' in d:
            o.name = d['name']
        if 'param_template_list' in d:
            o.param_template_list = d['param_template_list']
        if 'picture_url' in d:
            o.picture_url = d['picture_url']
        if 'preview_url' in d:
            o.preview_url = d['preview_url']
        if 'resolve_code' in d:
            o.resolve_code = d['resolve_code']
        if 'run_version' in d:
            o.run_version = d['run_version']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayUserSportshealthAccountFreezeModel(object):

    def __init__(self):
        self._memo = None
        self._open_id = None
        self._out_biz_channel = None
        self._out_biz_no = None
        self._pay_amount = None
        self._user_id = None

    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def out_biz_channel(self):
        return self._out_biz_channel

    @out_biz_channel.setter
    def out_biz_channel(self, value):
        self._out_biz_channel = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def pay_amount(self):
        return self._pay_amount

    @pay_amount.setter
    def pay_amount(self, value):
        self._pay_amount = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.out_biz_channel:
            if hasattr(self.out_biz_channel, 'to_alipay_dict'):
                params['out_biz_channel'] = self.out_biz_channel.to_alipay_dict()
            else:
                params['out_biz_channel'] = self.out_biz_channel
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.pay_amount:
            if hasattr(self.pay_amount, 'to_alipay_dict'):
                params['pay_amount'] = self.pay_amount.to_alipay_dict()
            else:
                params['pay_amount'] = self.pay_amount
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserSportshealthAccountFreezeModel()
        if 'memo' in d:
            o.memo = d['memo']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'out_biz_channel' in d:
            o.out_biz_channel = d['out_biz_channel']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'pay_amount' in d:
            o.pay_amount = d['pay_amount']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntMerchantExpandContractFacetofaceSignModel(object):

    def __init__(self):
        self._business_license_auth_pic = None
        self._business_license_no = None
        self._business_license_pic = None
        self._contact_email = None
        self._contact_mobile = None
        self._contact_name = None
        self._mcc_code = None
        self._out_biz_no = None
        self._shop_scene_pic = None
        self._shop_sign_board_pic = None
        self._special_license_pic = None

    @property
    def business_license_auth_pic(self):
        return self._business_license_auth_pic

    @business_license_auth_pic.setter
    def business_license_auth_pic(self, value):
        self._business_license_auth_pic = value
    @property
    def business_license_no(self):
        return self._business_license_no

    @business_license_no.setter
    def business_license_no(self, value):
        self._business_license_no = value
    @property
    def business_license_pic(self):
        return self._business_license_pic

    @business_license_pic.setter
    def business_license_pic(self, value):
        self._business_license_pic = value
    @property
    def contact_email(self):
        return self._contact_email

    @contact_email.setter
    def contact_email(self, value):
        self._contact_email = value
    @property
    def contact_mobile(self):
        return self._contact_mobile

    @contact_mobile.setter
    def contact_mobile(self, value):
        self._contact_mobile = value
    @property
    def contact_name(self):
        return self._contact_name

    @contact_name.setter
    def contact_name(self, value):
        self._contact_name = value
    @property
    def mcc_code(self):
        return self._mcc_code

    @mcc_code.setter
    def mcc_code(self, value):
        self._mcc_code = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def shop_scene_pic(self):
        return self._shop_scene_pic

    @shop_scene_pic.setter
    def shop_scene_pic(self, value):
        self._shop_scene_pic = value
    @property
    def shop_sign_board_pic(self):
        return self._shop_sign_board_pic

    @shop_sign_board_pic.setter
    def shop_sign_board_pic(self, value):
        self._shop_sign_board_pic = value
    @property
    def special_license_pic(self):
        return self._special_license_pic

    @special_license_pic.setter
    def special_license_pic(self, value):
        self._special_license_pic = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_license_auth_pic:
            if hasattr(self.business_license_auth_pic, 'to_alipay_dict'):
                params['business_license_auth_pic'] = self.business_license_auth_pic.to_alipay_dict()
            else:
                params['business_license_auth_pic'] = self.business_license_auth_pic
        if self.business_license_no:
            if hasattr(self.business_license_no, 'to_alipay_dict'):
                params['business_license_no'] = self.business_license_no.to_alipay_dict()
            else:
                params['business_license_no'] = self.business_license_no
        if self.business_license_pic:
            if hasattr(self.business_license_pic, 'to_alipay_dict'):
                params['business_license_pic'] = self.business_license_pic.to_alipay_dict()
            else:
                params['business_license_pic'] = self.business_license_pic
        if self.contact_email:
            if hasattr(self.contact_email, 'to_alipay_dict'):
                params['contact_email'] = self.contact_email.to_alipay_dict()
            else:
                params['contact_email'] = self.contact_email
        if self.contact_mobile:
            if hasattr(self.contact_mobile, 'to_alipay_dict'):
                params['contact_mobile'] = self.contact_mobile.to_alipay_dict()
            else:
                params['contact_mobile'] = self.contact_mobile
        if self.contact_name:
            if hasattr(self.contact_name, 'to_alipay_dict'):
                params['contact_name'] = self.contact_name.to_alipay_dict()
            else:
                params['contact_name'] = self.contact_name
        if self.mcc_code:
            if hasattr(self.mcc_code, 'to_alipay_dict'):
                params['mcc_code'] = self.mcc_code.to_alipay_dict()
            else:
                params['mcc_code'] = self.mcc_code
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.shop_scene_pic:
            if hasattr(self.shop_scene_pic, 'to_alipay_dict'):
                params['shop_scene_pic'] = self.shop_scene_pic.to_alipay_dict()
            else:
                params['shop_scene_pic'] = self.shop_scene_pic
        if self.shop_sign_board_pic:
            if hasattr(self.shop_sign_board_pic, 'to_alipay_dict'):
                params['shop_sign_board_pic'] = self.shop_sign_board_pic.to_alipay_dict()
            else:
                params['shop_sign_board_pic'] = self.shop_sign_board_pic
        if self.special_license_pic:
            if hasattr(self.special_license_pic, 'to_alipay_dict'):
                params['special_license_pic'] = self.special_license_pic.to_alipay_dict()
            else:
                params['special_license_pic'] = self.special_license_pic
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandContractFacetofaceSignModel()
        if 'business_license_auth_pic' in d:
            o.business_license_auth_pic = d['business_license_auth_pic']
        if 'business_license_no' in d:
            o.business_license_no = d['business_license_no']
        if 'business_license_pic' in d:
            o.business_license_pic = d['business_license_pic']
        if 'contact_email' in d:
            o.contact_email = d['contact_email']
        if 'contact_mobile' in d:
            o.contact_mobile = d['contact_mobile']
        if 'contact_name' in d:
            o.contact_name = d['contact_name']
        if 'mcc_code' in d:
            o.mcc_code = d['mcc_code']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'shop_scene_pic' in d:
            o.shop_scene_pic = d['shop_scene_pic']
        if 'shop_sign_board_pic' in d:
            o.shop_sign_board_pic = d['shop_sign_board_pic']
        if 'special_license_pic' in d:
            o.special_license_pic = d['special_license_pic']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CardLevelConfigDTO import CardLevelConfigDTO


class AlipayUserCardLevelSetModel(object):

    def __init__(self):
        self._card_level_config = None
        self._operate_type = None
        self._template_id = None

    @property
    def card_level_config(self):
        return self._card_level_config

    @card_level_config.setter
    def card_level_config(self, value):
        if isinstance(value, CardLevelConfigDTO):
            self._card_level_config = value
        else:
            self._card_level_config = CardLevelConfigDTO.from_alipay_dict(value)
    @property
    def operate_type(self):
        return self._operate_type

    @operate_type.setter
    def operate_type(self, value):
        self._operate_type = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.card_level_config:
            if hasattr(self.card_level_config, 'to_alipay_dict'):
                params['card_level_config'] = self.card_level_config.to_alipay_dict()
            else:
                params['card_level_config'] = self.card_level_config
        if self.operate_type:
            if hasattr(self.operate_type, 'to_alipay_dict'):
                params['operate_type'] = self.operate_type.to_alipay_dict()
            else:
                params['operate_type'] = self.operate_type
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserCardLevelSetModel()
        if 'card_level_config' in d:
            o.card_level_config = d['card_level_config']
        if 'operate_type' in d:
            o.operate_type = d['operate_type']
        if 'template_id' in d:
            o.template_id = d['template_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayPayAggrepayOrderCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayPayAggrepayOrderCreateResponse, self).__init__()
        self._pay_data = None

    @property
    def pay_data(self):
        return self._pay_data

    @pay_data.setter
    def pay_data(self, value):
        self._pay_data = value

    def parse_response_content(self, response_content):
        response = super(AlipayPayAggrepayOrderCreateResponse, self).parse_response_content(response_content)
        if 'pay_data' in response:
            self.pay_data = response['pay_data']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TagDTO import TagDTO


class TwoCategoryDTO(object):

    def __init__(self):
        self._category_id = None
        self._category_name = None
        self._parent_category_id = None
        self._tag_dto_list = None

    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def category_name(self):
        return self._category_name

    @category_name.setter
    def category_name(self, value):
        self._category_name = value
    @property
    def parent_category_id(self):
        return self._parent_category_id

    @parent_category_id.setter
    def parent_category_id(self, value):
        self._parent_category_id = value
    @property
    def tag_dto_list(self):
        return self._tag_dto_list

    @tag_dto_list.setter
    def tag_dto_list(self, value):
        if isinstance(value, list):
            self._tag_dto_list = list()
            for i in value:
                if isinstance(i, TagDTO):
                    self._tag_dto_list.append(i)
                else:
                    self._tag_dto_list.append(TagDTO.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.category_name:
            if hasattr(self.category_name, 'to_alipay_dict'):
                params['category_name'] = self.category_name.to_alipay_dict()
            else:
                params['category_name'] = self.category_name
        if self.parent_category_id:
            if hasattr(self.parent_category_id, 'to_alipay_dict'):
                params['parent_category_id'] = self.parent_category_id.to_alipay_dict()
            else:
                params['parent_category_id'] = self.parent_category_id
        if self.tag_dto_list:
            if isinstance(self.tag_dto_list, list):
                for i in range(0, len(self.tag_dto_list)):
                    element = self.tag_dto_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.tag_dto_list[i] = element.to_alipay_dict()
            if hasattr(self.tag_dto_list, 'to_alipay_dict'):
                params['tag_dto_list'] = self.tag_dto_list.to_alipay_dict()
            else:
                params['tag_dto_list'] = self.tag_dto_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TwoCategoryDTO()
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'category_name' in d:
            o.category_name = d['category_name']
        if 'parent_category_id' in d:
            o.parent_category_id = d['parent_category_id']
        if 'tag_dto_list' in d:
            o.tag_dto_list = d['tag_dto_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AppItemSPUPriceVO(object):

    def __init__(self):
        self._has_price = None
        self._original_price = None
        self._original_price_max = None
        self._original_price_min = None
        self._price = None
        self._price_max = None
        self._price_min = None
        self._price_unit = None

    @property
    def has_price(self):
        return self._has_price

    @has_price.setter
    def has_price(self, value):
        self._has_price = value
    @property
    def original_price(self):
        return self._original_price

    @original_price.setter
    def original_price(self, value):
        self._original_price = value
    @property
    def original_price_max(self):
        return self._original_price_max

    @original_price_max.setter
    def original_price_max(self, value):
        self._original_price_max = value
    @property
    def original_price_min(self):
        return self._original_price_min

    @original_price_min.setter
    def original_price_min(self, value):
        self._original_price_min = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def price_max(self):
        return self._price_max

    @price_max.setter
    def price_max(self, value):
        self._price_max = value
    @property
    def price_min(self):
        return self._price_min

    @price_min.setter
    def price_min(self, value):
        self._price_min = value
    @property
    def price_unit(self):
        return self._price_unit

    @price_unit.setter
    def price_unit(self, value):
        self._price_unit = value


    def to_alipay_dict(self):
        params = dict()
        if self.has_price:
            if hasattr(self.has_price, 'to_alipay_dict'):
                params['has_price'] = self.has_price.to_alipay_dict()
            else:
                params['has_price'] = self.has_price
        if self.original_price:
            if hasattr(self.original_price, 'to_alipay_dict'):
                params['original_price'] = self.original_price.to_alipay_dict()
            else:
                params['original_price'] = self.original_price
        if self.original_price_max:
            if hasattr(self.original_price_max, 'to_alipay_dict'):
                params['original_price_max'] = self.original_price_max.to_alipay_dict()
            else:
                params['original_price_max'] = self.original_price_max
        if self.original_price_min:
            if hasattr(self.original_price_min, 'to_alipay_dict'):
                params['original_price_min'] = self.original_price_min.to_alipay_dict()
            else:
                params['original_price_min'] = self.original_price_min
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.price_max:
            if hasattr(self.price_max, 'to_alipay_dict'):
                params['price_max'] = self.price_max.to_alipay_dict()
            else:
                params['price_max'] = self.price_max
        if self.price_min:
            if hasattr(self.price_min, 'to_alipay_dict'):
                params['price_min'] = self.price_min.to_alipay_dict()
            else:
                params['price_min'] = self.price_min
        if self.price_unit:
            if hasattr(self.price_unit, 'to_alipay_dict'):
                params['price_unit'] = self.price_unit.to_alipay_dict()
            else:
                params['price_unit'] = self.price_unit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AppItemSPUPriceVO()
        if 'has_price' in d:
            o.has_price = d['has_price']
        if 'original_price' in d:
            o.original_price = d['original_price']
        if 'original_price_max' in d:
            o.original_price_max = d['original_price_max']
        if 'original_price_min' in d:
            o.original_price_min = d['original_price_min']
        if 'price' in d:
            o.price = d['price']
        if 'price_max' in d:
            o.price_max = d['price_max']
        if 'price_min' in d:
            o.price_min = d['price_min']
        if 'price_unit' in d:
            o.price_unit = d['price_unit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CrowdOperations(object):

    def __init__(self):
        self._crowd_id = None
        self._deadline = None
        self._operator = None
        self._ttl = None

    @property
    def crowd_id(self):
        return self._crowd_id

    @crowd_id.setter
    def crowd_id(self, value):
        self._crowd_id = value
    @property
    def deadline(self):
        return self._deadline

    @deadline.setter
    def deadline(self, value):
        self._deadline = value
    @property
    def operator(self):
        return self._operator

    @operator.setter
    def operator(self, value):
        self._operator = value
    @property
    def ttl(self):
        return self._ttl

    @ttl.setter
    def ttl(self, value):
        self._ttl = value


    def to_alipay_dict(self):
        params = dict()
        if self.crowd_id:
            if hasattr(self.crowd_id, 'to_alipay_dict'):
                params['crowd_id'] = self.crowd_id.to_alipay_dict()
            else:
                params['crowd_id'] = self.crowd_id
        if self.deadline:
            if hasattr(self.deadline, 'to_alipay_dict'):
                params['deadline'] = self.deadline.to_alipay_dict()
            else:
                params['deadline'] = self.deadline
        if self.operator:
            if hasattr(self.operator, 'to_alipay_dict'):
                params['operator'] = self.operator.to_alipay_dict()
            else:
                params['operator'] = self.operator
        if self.ttl:
            if hasattr(self.ttl, 'to_alipay_dict'):
                params['ttl'] = self.ttl.to_alipay_dict()
            else:
                params['ttl'] = self.ttl
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CrowdOperations()
        if 'crowd_id' in d:
            o.crowd_id = d['crowd_id']
        if 'deadline' in d:
            o.deadline = d['deadline']
        if 'operator' in d:
            o.operator = d['operator']
        if 'ttl' in d:
            o.ttl = d['ttl']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossFncGfsettleprodInvoicetaxlossQueryModel(object):

    def __init__(self):
        self._bill_nos = None
        self._settle_ip_role_id = None

    @property
    def bill_nos(self):
        return self._bill_nos

    @bill_nos.setter
    def bill_nos(self, value):
        self._bill_nos = value
    @property
    def settle_ip_role_id(self):
        return self._settle_ip_role_id

    @settle_ip_role_id.setter
    def settle_ip_role_id(self, value):
        self._settle_ip_role_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_nos:
            if hasattr(self.bill_nos, 'to_alipay_dict'):
                params['bill_nos'] = self.bill_nos.to_alipay_dict()
            else:
                params['bill_nos'] = self.bill_nos
        if self.settle_ip_role_id:
            if hasattr(self.settle_ip_role_id, 'to_alipay_dict'):
                params['settle_ip_role_id'] = self.settle_ip_role_id.to_alipay_dict()
            else:
                params['settle_ip_role_id'] = self.settle_ip_role_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncGfsettleprodInvoicetaxlossQueryModel()
        if 'bill_nos' in d:
            o.bill_nos = d['bill_nos']
        if 'settle_ip_role_id' in d:
            o.settle_ip_role_id = d['settle_ip_role_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FileBaseInfoResponse(object):

    def __init__(self):
        self._absolute_path = None
        self._download_url = None
        self._enable = None
        self._file_id = None
        self._file_name = None
        self._file_type = None
        self._path = None

    @property
    def absolute_path(self):
        return self._absolute_path

    @absolute_path.setter
    def absolute_path(self, value):
        self._absolute_path = value
    @property
    def download_url(self):
        return self._download_url

    @download_url.setter
    def download_url(self, value):
        self._download_url = value
    @property
    def enable(self):
        return self._enable

    @enable.setter
    def enable(self, value):
        self._enable = value
    @property
    def file_id(self):
        return self._file_id

    @file_id.setter
    def file_id(self, value):
        self._file_id = value
    @property
    def file_name(self):
        return self._file_name

    @file_name.setter
    def file_name(self, value):
        self._file_name = value
    @property
    def file_type(self):
        return self._file_type

    @file_type.setter
    def file_type(self, value):
        self._file_type = value
    @property
    def path(self):
        return self._path

    @path.setter
    def path(self, value):
        self._path = value


    def to_alipay_dict(self):
        params = dict()
        if self.absolute_path:
            if hasattr(self.absolute_path, 'to_alipay_dict'):
                params['absolute_path'] = self.absolute_path.to_alipay_dict()
            else:
                params['absolute_path'] = self.absolute_path
        if self.download_url:
            if hasattr(self.download_url, 'to_alipay_dict'):
                params['download_url'] = self.download_url.to_alipay_dict()
            else:
                params['download_url'] = self.download_url
        if self.enable:
            if hasattr(self.enable, 'to_alipay_dict'):
                params['enable'] = self.enable.to_alipay_dict()
            else:
                params['enable'] = self.enable
        if self.file_id:
            if hasattr(self.file_id, 'to_alipay_dict'):
                params['file_id'] = self.file_id.to_alipay_dict()
            else:
                params['file_id'] = self.file_id
        if self.file_name:
            if hasattr(self.file_name, 'to_alipay_dict'):
                params['file_name'] = self.file_name.to_alipay_dict()
            else:
                params['file_name'] = self.file_name
        if self.file_type:
            if hasattr(self.file_type, 'to_alipay_dict'):
                params['file_type'] = self.file_type.to_alipay_dict()
            else:
                params['file_type'] = self.file_type
        if self.path:
            if hasattr(self.path, 'to_alipay_dict'):
                params['path'] = self.path.to_alipay_dict()
            else:
                params['path'] = self.path
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FileBaseInfoResponse()
        if 'absolute_path' in d:
            o.absolute_path = d['absolute_path']
        if 'download_url' in d:
            o.download_url = d['download_url']
        if 'enable' in d:
            o.enable = d['enable']
        if 'file_id' in d:
            o.file_id = d['file_id']
        if 'file_name' in d:
            o.file_name = d['file_name']
        if 'file_type' in d:
            o.file_type = d['file_type']
        if 'path' in d:
            o.path = d['path']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CateInfo import CateInfo
from alipay.aop.api.domain.ShopMerchantInfo import ShopMerchantInfo
from alipay.aop.api.domain.CourseSKUInfo import CourseSKUInfo
from alipay.aop.api.domain.CourseTagInfo import CourseTagInfo


class AlipayCommerceEducateTrainCourseModifyModel(object):

    def __init__(self):
        self._biz_type = None
        self._brief = None
        self._cate_infos = None
        self._course_id = None
        self._desc = None
        self._merchant_info = None
        self._name = None
        self._open_time = None
        self._out_course_id = None
        self._pic = None
        self._scene_type = None
        self._sku_infos = None
        self._source_type = None
        self._tag_infos = None
        self._url = None
        self._video = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def brief(self):
        return self._brief

    @brief.setter
    def brief(self, value):
        self._brief = value
    @property
    def cate_infos(self):
        return self._cate_infos

    @cate_infos.setter
    def cate_infos(self, value):
        if isinstance(value, list):
            self._cate_infos = list()
            for i in value:
                if isinstance(i, CateInfo):
                    self._cate_infos.append(i)
                else:
                    self._cate_infos.append(CateInfo.from_alipay_dict(i))
    @property
    def course_id(self):
        return self._course_id

    @course_id.setter
    def course_id(self, value):
        self._course_id = value
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def merchant_info(self):
        return self._merchant_info

    @merchant_info.setter
    def merchant_info(self, value):
        if isinstance(value, ShopMerchantInfo):
            self._merchant_info = value
        else:
            self._merchant_info = ShopMerchantInfo.from_alipay_dict(value)
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def open_time(self):
        return self._open_time

    @open_time.setter
    def open_time(self, value):
        self._open_time = value
    @property
    def out_course_id(self):
        return self._out_course_id

    @out_course_id.setter
    def out_course_id(self, value):
        self._out_course_id = value
    @property
    def pic(self):
        return self._pic

    @pic.setter
    def pic(self, value):
        self._pic = value
    @property
    def scene_type(self):
        return self._scene_type

    @scene_type.setter
    def scene_type(self, value):
        self._scene_type = value
    @property
    def sku_infos(self):
        return self._sku_infos

    @sku_infos.setter
    def sku_infos(self, value):
        if isinstance(value, list):
            self._sku_infos = list()
            for i in value:
                if isinstance(i, CourseSKUInfo):
                    self._sku_infos.append(i)
                else:
                    self._sku_infos.append(CourseSKUInfo.from_alipay_dict(i))
    @property
    def source_type(self):
        return self._source_type

    @source_type.setter
    def source_type(self, value):
        self._source_type = value
    @property
    def tag_infos(self):
        return self._tag_infos

    @tag_infos.setter
    def tag_infos(self, value):
        if isinstance(value, list):
            self._tag_infos = list()
            for i in value:
                if isinstance(i, CourseTagInfo):
                    self._tag_infos.append(i)
                else:
                    self._tag_infos.append(CourseTagInfo.from_alipay_dict(i))
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value
    @property
    def video(self):
        return self._video

    @video.setter
    def video(self, value):
        self._video = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.brief:
            if hasattr(self.brief, 'to_alipay_dict'):
                params['brief'] = self.brief.to_alipay_dict()
            else:
                params['brief'] = self.brief
        if self.cate_infos:
            if isinstance(self.cate_infos, list):
                for i in range(0, len(self.cate_infos)):
                    element = self.cate_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.cate_infos[i] = element.to_alipay_dict()
            if hasattr(self.cate_infos, 'to_alipay_dict'):
                params['cate_infos'] = self.cate_infos.to_alipay_dict()
            else:
                params['cate_infos'] = self.cate_infos
        if self.course_id:
            if hasattr(self.course_id, 'to_alipay_dict'):
                params['course_id'] = self.course_id.to_alipay_dict()
            else:
                params['course_id'] = self.course_id
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.merchant_info:
            if hasattr(self.merchant_info, 'to_alipay_dict'):
                params['merchant_info'] = self.merchant_info.to_alipay_dict()
            else:
                params['merchant_info'] = self.merchant_info
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.open_time:
            if hasattr(self.open_time, 'to_alipay_dict'):
                params['open_time'] = self.open_time.to_alipay_dict()
            else:
                params['open_time'] = self.open_time
        if self.out_course_id:
            if hasattr(self.out_course_id, 'to_alipay_dict'):
                params['out_course_id'] = self.out_course_id.to_alipay_dict()
            else:
                params['out_course_id'] = self.out_course_id
        if self.pic:
            if hasattr(self.pic, 'to_alipay_dict'):
                params['pic'] = self.pic.to_alipay_dict()
            else:
                params['pic'] = self.pic
        if self.scene_type:
            if hasattr(self.scene_type, 'to_alipay_dict'):
                params['scene_type'] = self.scene_type.to_alipay_dict()
            else:
                params['scene_type'] = self.scene_type
        if self.sku_infos:
            if isinstance(self.sku_infos, list):
                for i in range(0, len(self.sku_infos)):
                    element = self.sku_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.sku_infos[i] = element.to_alipay_dict()
            if hasattr(self.sku_infos, 'to_alipay_dict'):
                params['sku_infos'] = self.sku_infos.to_alipay_dict()
            else:
                params['sku_infos'] = self.sku_infos
        if self.source_type:
            if hasattr(self.source_type, 'to_alipay_dict'):
                params['source_type'] = self.source_type.to_alipay_dict()
            else:
                params['source_type'] = self.source_type
        if self.tag_infos:
            if isinstance(self.tag_infos, list):
                for i in range(0, len(self.tag_infos)):
                    element = self.tag_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.tag_infos[i] = element.to_alipay_dict()
            if hasattr(self.tag_infos, 'to_alipay_dict'):
                params['tag_infos'] = self.tag_infos.to_alipay_dict()
            else:
                params['tag_infos'] = self.tag_infos
        if self.url:
            if hasattr(self.url, 'to_alipay_dict'):
                params['url'] = self.url.to_alipay_dict()
            else:
                params['url'] = self.url
        if self.video:
            if hasattr(self.video, 'to_alipay_dict'):
                params['video'] = self.video.to_alipay_dict()
            else:
                params['video'] = self.video
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateTrainCourseModifyModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'brief' in d:
            o.brief = d['brief']
        if 'cate_infos' in d:
            o.cate_infos = d['cate_infos']
        if 'course_id' in d:
            o.course_id = d['course_id']
        if 'desc' in d:
            o.desc = d['desc']
        if 'merchant_info' in d:
            o.merchant_info = d['merchant_info']
        if 'name' in d:
            o.name = d['name']
        if 'open_time' in d:
            o.open_time = d['open_time']
        if 'out_course_id' in d:
            o.out_course_id = d['out_course_id']
        if 'pic' in d:
            o.pic = d['pic']
        if 'scene_type' in d:
            o.scene_type = d['scene_type']
        if 'sku_infos' in d:
            o.sku_infos = d['sku_infos']
        if 'source_type' in d:
            o.source_type = d['source_type']
        if 'tag_infos' in d:
            o.tag_infos = d['tag_infos']
        if 'url' in d:
            o.url = d['url']
        if 'video' in d:
            o.video = d['video']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BillKeyInfo(object):

    def __init__(self):
        self._billkey = None
        self._biz_type = None
        self._charge_inst = None
        self._city = None
        self._country = None
        self._province = None
        self._sub_biz_type = None

    @property
    def billkey(self):
        return self._billkey

    @billkey.setter
    def billkey(self, value):
        self._billkey = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def charge_inst(self):
        return self._charge_inst

    @charge_inst.setter
    def charge_inst(self, value):
        self._charge_inst = value
    @property
    def city(self):
        return self._city

    @city.setter
    def city(self, value):
        self._city = value
    @property
    def country(self):
        return self._country

    @country.setter
    def country(self, value):
        self._country = value
    @property
    def province(self):
        return self._province

    @province.setter
    def province(self, value):
        self._province = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.billkey:
            if hasattr(self.billkey, 'to_alipay_dict'):
                params['billkey'] = self.billkey.to_alipay_dict()
            else:
                params['billkey'] = self.billkey
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.charge_inst:
            if hasattr(self.charge_inst, 'to_alipay_dict'):
                params['charge_inst'] = self.charge_inst.to_alipay_dict()
            else:
                params['charge_inst'] = self.charge_inst
        if self.city:
            if hasattr(self.city, 'to_alipay_dict'):
                params['city'] = self.city.to_alipay_dict()
            else:
                params['city'] = self.city
        if self.country:
            if hasattr(self.country, 'to_alipay_dict'):
                params['country'] = self.country.to_alipay_dict()
            else:
                params['country'] = self.country
        if self.province:
            if hasattr(self.province, 'to_alipay_dict'):
                params['province'] = self.province.to_alipay_dict()
            else:
                params['province'] = self.province
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BillKeyInfo()
        if 'billkey' in d:
            o.billkey = d['billkey']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'charge_inst' in d:
            o.charge_inst = d['charge_inst']
        if 'city' in d:
            o.city = d['city']
        if 'country' in d:
            o.country = d['country']
        if 'province' in d:
            o.province = d['province']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInvoiceTitleSyncModel(object):

    def __init__(self):
        self._open_bank_account = None
        self._open_bank_name = None
        self._open_id = None
        self._tax_register_no = None
        self._title_name = None
        self._user_address = None
        self._user_id = None
        self._user_mobile = None

    @property
    def open_bank_account(self):
        return self._open_bank_account

    @open_bank_account.setter
    def open_bank_account(self, value):
        self._open_bank_account = value
    @property
    def open_bank_name(self):
        return self._open_bank_name

    @open_bank_name.setter
    def open_bank_name(self, value):
        self._open_bank_name = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def tax_register_no(self):
        return self._tax_register_no

    @tax_register_no.setter
    def tax_register_no(self, value):
        self._tax_register_no = value
    @property
    def title_name(self):
        return self._title_name

    @title_name.setter
    def title_name(self, value):
        self._title_name = value
    @property
    def user_address(self):
        return self._user_address

    @user_address.setter
    def user_address(self, value):
        self._user_address = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def user_mobile(self):
        return self._user_mobile

    @user_mobile.setter
    def user_mobile(self, value):
        self._user_mobile = value


    def to_alipay_dict(self):
        params = dict()
        if self.open_bank_account:
            if hasattr(self.open_bank_account, 'to_alipay_dict'):
                params['open_bank_account'] = self.open_bank_account.to_alipay_dict()
            else:
                params['open_bank_account'] = self.open_bank_account
        if self.open_bank_name:
            if hasattr(self.open_bank_name, 'to_alipay_dict'):
                params['open_bank_name'] = self.open_bank_name.to_alipay_dict()
            else:
                params['open_bank_name'] = self.open_bank_name
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.tax_register_no:
            if hasattr(self.tax_register_no, 'to_alipay_dict'):
                params['tax_register_no'] = self.tax_register_no.to_alipay_dict()
            else:
                params['tax_register_no'] = self.tax_register_no
        if self.title_name:
            if hasattr(self.title_name, 'to_alipay_dict'):
                params['title_name'] = self.title_name.to_alipay_dict()
            else:
                params['title_name'] = self.title_name
        if self.user_address:
            if hasattr(self.user_address, 'to_alipay_dict'):
                params['user_address'] = self.user_address.to_alipay_dict()
            else:
                params['user_address'] = self.user_address
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.user_mobile:
            if hasattr(self.user_mobile, 'to_alipay_dict'):
                params['user_mobile'] = self.user_mobile.to_alipay_dict()
            else:
                params['user_mobile'] = self.user_mobile
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInvoiceTitleSyncModel()
        if 'open_bank_account' in d:
            o.open_bank_account = d['open_bank_account']
        if 'open_bank_name' in d:
            o.open_bank_name = d['open_bank_name']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'tax_register_no' in d:
            o.tax_register_no = d['tax_register_no']
        if 'title_name' in d:
            o.title_name = d['title_name']
        if 'user_address' in d:
            o.user_address = d['user_address']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'user_mobile' in d:
            o.user_mobile = d['user_mobile']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InstalmentPlanTuitionDTO(object):

    def __init__(self):
        self._amount = None
        self._biz_time = None
        self._order_id = None
        self._partner_id = None
        self._plan_open_id = None
        self._schedule_time = None
        self._serial_no = None
        self._smid = None
        self._status = None
        self._trade_no = None
        self._user_id = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def biz_time(self):
        return self._biz_time

    @biz_time.setter
    def biz_time(self, value):
        self._biz_time = value
    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def plan_open_id(self):
        return self._plan_open_id

    @plan_open_id.setter
    def plan_open_id(self, value):
        self._plan_open_id = value
    @property
    def schedule_time(self):
        return self._schedule_time

    @schedule_time.setter
    def schedule_time(self, value):
        self._schedule_time = value
    @property
    def serial_no(self):
        return self._serial_no

    @serial_no.setter
    def serial_no(self, value):
        self._serial_no = value
    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.amount:
            if hasattr(self.amount, 'to_alipay_dict'):
                params['amount'] = self.amount.to_alipay_dict()
            else:
                params['amount'] = self.amount
        if self.biz_time:
            if hasattr(self.biz_time, 'to_alipay_dict'):
                params['biz_time'] = self.biz_time.to_alipay_dict()
            else:
                params['biz_time'] = self.biz_time
        if self.order_id:
            if hasattr(self.order_id, 'to_alipay_dict'):
                params['order_id'] = self.order_id.to_alipay_dict()
            else:
                params['order_id'] = self.order_id
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.plan_open_id:
            if hasattr(self.plan_open_id, 'to_alipay_dict'):
                params['plan_open_id'] = self.plan_open_id.to_alipay_dict()
            else:
                params['plan_open_id'] = self.plan_open_id
        if self.schedule_time:
            if hasattr(self.schedule_time, 'to_alipay_dict'):
                params['schedule_time'] = self.schedule_time.to_alipay_dict()
            else:
                params['schedule_time'] = self.schedule_time
        if self.serial_no:
            if hasattr(self.serial_no, 'to_alipay_dict'):
                params['serial_no'] = self.serial_no.to_alipay_dict()
            else:
                params['serial_no'] = self.serial_no
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InstalmentPlanTuitionDTO()
        if 'amount' in d:
            o.amount = d['amount']
        if 'biz_time' in d:
            o.biz_time = d['biz_time']
        if 'order_id' in d:
            o.order_id = d['order_id']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'plan_open_id' in d:
            o.plan_open_id = d['plan_open_id']
        if 'schedule_time' in d:
            o.schedule_time = d['schedule_time']
        if 'serial_no' in d:
            o.serial_no = d['serial_no']
        if 'smid' in d:
            o.smid = d['smid']
        if 'status' in d:
            o.status = d['status']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o


